Fetch historical enrollment from MD Planning
Source:R/get_raw_enrollment.R
fetch_historical_enrollment.RdDownloads enrollment data for multiple years from the Maryland Department of Planning. This is useful for longitudinal analysis.
R/get_raw_enrollment.R
fetch_historical_enrollment.RdDownloads enrollment data for multiple years from the Maryland Department of Planning. This is useful for longitudinal analysis.