Download Maryland Report Card enrollment data
Source:R/get_raw_enrollment.R
download_md_reportcard_enrollment.RdAttempts to fetch enrollment data from the Maryland Report Card website. This function handles the web interaction required to download data.