Downloads assessment data from the Maryland Report Card system. Currently provides MCAP participation rate data for 2022-present. Proficiency data requires manual download from the Report Card interface.
Usage
get_raw_assessment(end_year, data_type = c("participation", "proficiency"))Value
Data frame with assessment data including:
School and district identifiers
Assessment type (ELA, Math, Science)
Student group breakdowns
Participation rates (for participation data)
Details
See also
fetch_assessment for the main user-facing function
import_local_assessment for loading manually downloaded files
Examples
if (FALSE) { # \dontrun{
# Download 2024 MCAP participation data
assess_2024 <- get_raw_assessment(2024)
# View available student groups
unique(assess_2024$student_group)
} # }